/* client.c */

#include <stdio.h>
#include <stdlib.h>
#include <assert.h>
#include <string.h>
#include <errno.h>

#if defined(__linux__)
#include <unistd.h>
#endif

#include "conn.h"

static conn_t con;

static void cleanup(void)
{
	conn_close(&con);
}

int main(int argc, char ** argv)
{
	long host = (127 << 24) + (0 << 16) + (0 << 8) + (1 << 0);
	struct timeval t;
	int rc;
	char buf[128];
	fd_set fds;
	short port;

	atexit(cleanup);

	port = (argc < 2) ? 9900 : atoi(argv[1]);
	if (conn_open(&con, host, port) < 0) {
		exit(-1);
	}

	for (;;) {
		FD_ZERO(&fds);
		FD_SET(0, &fds);
		FD_SET(con.sock, &fds);
		rc = select(con.sock+1, &fds, NULL, NULL, NULL);
		if (rc < 0) {
			printf("error while waiting for input.\n");
			perror("select");
			break;
		}
		if (FD_ISSET(0, &fds)) { /* input from stdin */
			memset(buf, 0, sizeof(buf));
			rc = read(0, buf, sizeof(buf));
			if (rc < 0) {
				printf("error while reading from stdin.\n");
				perror("read");
				continue;
			}
			rc = conn_write(&con, buf, rc);
			if (rc < 0) {
				printf("error while writing to connection.\n");
				perror("write");
				break;
			}
		}
		if (FD_ISSET(con.sock, &fds)) { /* input from connection */
			memset(buf, 0, sizeof(buf));
			rc = conn_read(&con, buf, sizeof(buf));
			if (rc < 0) {
				printf("error while reading from connection.\n");
				perror("read");
				break;
			}
			printf("recv: [%s]\n", buf);
		}
	}
	conn_close(&con);
	return 0;
}

