#include "game.h"
#include <assert.h>
#include <string.h>

void field_init(field_t * f)
{
	assert(f);
	memset(f, 0, sizeof(field_t));
}

void coord_init(coord_t * c)
{
	assert(c);
	c->x = -1;
	c->y = -1;
}

void state_init(state_t * s)
{
	assert(s);
	field_init(&s->field);
}

player_t state_get(state_t * state, int32_t x, int32_t y)
{
	assert(state);
	assert(x >= 0 && x < FIELD_N);
	assert(y >= 0 && y < FIELD_N);
	return state->field.data[x][y];
}

player_t state_get_coord(state_t * state, const coord_t * c)
{
	assert(state);
	assert(c);
	return state_get(state, c->x, c->y);
}

void state_set(state_t * state, int32_t x, int32_t y, player_t p)
{
	assert(state);
	assert(x >= 0 && x < FIELD_N);
	assert(y >= 0 && y < FIELD_N);
	state->field.data[x][y] = p;
}

void state_set_coord(state_t * state, const coord_t * c, player_t p)
{
	assert(state);
	assert(c);
	state_set(state, c->x, c->y, p);
}

int state_move_player(state_t * state,
	const coord_t * from, const coord_t * to, player_t player)
{
	assert(state);
	assert(from);
	assert(to);

	if (state_get_coord(state, from) != player) return -1;
	if (state_get_coord(state, to) != 0) return -1;

	state_set_coord(state, from, 0);
	state_set_coord(state, to, player);
	return 0;
}

int state_remove_player(state_t * state, player_t player)
{
	int x, y;

	assert(state);

	for (y = 0; y < FIELD_N; ++y) {
		for (x = 0; x < FIELD_N; ++x) {
			if (state_get(state, x, y) == player) {
				state_set(state, x, y, 0);
				return 0;
			}
		}
	}
	return -1;
}

